(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     49342,       1493]*)
(*NotebookOutlinePosition[     50165,       1522]*)
(*  CellTagsIndexPosition[     50121,       1518]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Convolution", "Section"],

Cell[TextData[{
  "The convolution of two functions",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\(f(x)\)\(\ \)\)\)\)]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`g(x)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(f(x)\)*\(g(x)\)\)]],
  " is defined to be\n",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\( f(
            u)\) \(g(x - u)\) \[DifferentialD]u\)]],
  "\n",
  ",which means that the area of the product of two functions becomes the \
height of the convolution function. "
}], "Text"],

Cell["\<\
Example: Find the distribution of Z=X+Y, X~Uniform[0,1], Y~Uniform[0,2]\
\>", "Text"],

Cell["\<\
Plot of probability density function of both X and Y using \"UnitStep\" \
function. \
\>", "Text"],

Cell[BoxData[
    \(f[x_] := UnitStep[x] - UnitStep[x - 1]\)], "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[
    \(g[x_] := \(1\/2\) \((UnitStep[x] - UnitStep[x - 2])\)\)], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    \(\(SetOptions[Integrate, Assumptions \[Rule] {x < 0}];\)\)], "Input",
  CellLabel->"In[3]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity] f[u]\ g[
          x - u] \[DifferentialD]u\)], "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[
    \(1\/2\ \((\((\(-3\) + x)\)\ UnitStep[\(-3\) + x] - \((\(-2\) + 
                x)\)\ UnitStep[\(-2\) + x] - \((\(-1\) + 
                x)\)\ UnitStep[\(-1\) + x] + x\ UnitStep[x])\)\)], "Output",
  CellLabel->"Out[6]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[%, {x, 0, 3}]\)], "Input",
  CellLabel->"In[7]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.0147151 1.17721 [
[.18254 .00222 -9 -9 ]
[.18254 .00222 9 0 ]
[.34127 .00222 -3 -9 ]
[.34127 .00222 3 0 ]
[.5 .00222 -9 -9 ]
[.5 .00222 9 0 ]
[.65873 .00222 -3 -9 ]
[.65873 .00222 3 0 ]
[.81746 .00222 -9 -9 ]
[.81746 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .13244 -18 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .25016 -18 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .36788 -18 -4.5 ]
[.01131 .36788 0 4.5 ]
[.01131 .4856 -18 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .60332 -18 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .01472 m
.18254 .02097 L
s
[(0.5)] .18254 .00222 0 1 Mshowa
.34127 .01472 m
.34127 .02097 L
s
[(1)] .34127 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(1.5)] .5 .00222 0 1 Mshowa
.65873 .01472 m
.65873 .02097 L
s
[(2)] .65873 .00222 0 1 Mshowa
.81746 .01472 m
.81746 .02097 L
s
[(2.5)] .81746 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(3)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.05556 .01472 m
.05556 .01847 L
s
.0873 .01472 m
.0873 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.15079 .01472 m
.15079 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.24603 .01472 m
.24603 .01847 L
s
.27778 .01472 m
.27778 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.37302 .01472 m
.37302 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.43651 .01472 m
.43651 .01847 L
s
.46825 .01472 m
.46825 .01847 L
s
.53175 .01472 m
.53175 .01847 L
s
.56349 .01472 m
.56349 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62698 .01472 m
.62698 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.72222 .01472 m
.72222 .01847 L
s
.75397 .01472 m
.75397 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.84921 .01472 m
.84921 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.9127 .01472 m
.9127 .01847 L
s
.94444 .01472 m
.94444 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13244 m
.03006 .13244 L
s
[(0.1)] .01131 .13244 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(0.2)] .01131 .25016 1 0 Mshowa
.02381 .36788 m
.03006 .36788 L
s
[(0.3)] .01131 .36788 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(0.4)] .01131 .4856 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(0.5)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .03826 m
.02756 .03826 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .08535 m
.02756 .08535 L
s
.02381 .10889 m
.02756 .10889 L
s
.02381 .15598 m
.02756 .15598 L
s
.02381 .17952 m
.02756 .17952 L
s
.02381 .20307 m
.02756 .20307 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .2737 m
.02756 .2737 L
s
.02381 .29724 m
.02756 .29724 L
s
.02381 .32079 m
.02756 .32079 L
s
.02381 .34433 m
.02756 .34433 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .41497 m
.02756 .41497 L
s
.02381 .43851 m
.02756 .43851 L
s
.02381 .46205 m
.02756 .46205 L
s
.02381 .50914 m
.02756 .50914 L
s
.02381 .53269 m
.02756 .53269 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57977 m
.02756 .57977 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .08635 L
.10458 .16447 L
.14415 .23784 L
.18221 .3084 L
.22272 .38351 L
.26171 .45581 L
.30316 .53265 L
.32392 .57115 L
.33304 .58806 L
.33788 .59703 L
.33927 .59962 L
.33996 .60089 L
.3406 .60207 L
.34179 .60332 L
.34309 .60332 L
.35271 .60332 L
.36173 .60332 L
.3815 .60332 L
.42063 .60332 L
.46221 .60332 L
.50228 .60332 L
.54083 .60332 L
.58183 .60332 L
.60225 .60332 L
.62132 .60332 L
.63965 .60332 L
.64492 .60332 L
.64992 .60332 L
.65441 .60332 L
.65564 .60332 L
.65694 .60332 L
.65806 .60332 L
.65929 .60228 L
.66051 .60002 L
.66164 .59793 L
.66421 .59316 L
.66938 .58357 L
.67864 .56641 L
.69949 .52774 L
.73854 .45535 L
.78004 .3784 L
.82002 .30427 L
.85849 .23295 L
.8994 .15709 L
.93881 .08403 L
.97619 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[7]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo000iOol2
0004Ool20004Ool2000ROol5000POol50002Ool20004Ool2000SOol4000QOol40003Ool20004Ool2
000SOol20007Ool003Qoo`04001oogoo0008Ool01000Oomoo`008goo00<007ooOol08Woo00<007oo
Ool01goo00@007ooOol0029oo`03001oogoo029oo`03001oogoo00Uoo`04001oogoo000QOol01000
Oomoo`001Woo000hOol01000Oomoo`002goo00<007ooOol08Goo00<007ooOol08Woo00<007ooOol0
2Woo00<007ooOol08Goo00<007ooOol08Woo00<007ooOol02goo00<007ooOol08Goo00<007ooOol0
1Goo000hOol01000Oomoo`002Goo0P0097oo00<007ooOol08Woo00<007ooOol027oo0P009Goo00<0
07ooOol08Woo00<007ooOol027oo0P009Goo00<007ooOol017oo000hOol01000Oomoo`002Goo00<0
07ooOol08goo00<007ooOol08Woo00<007ooOol027oo00<007ooOol08Woo00@007ooOol0025oo`04
001oogoo0009Ool00`00Oomoo`0QOol01000Oomoo`001Woo000iOol2000:Ool3000ROol2000SOol2
000:Ool3000SOol2000SOol2000:Ool3000ROol20007Ool00?moob5oo`005Goo00<007ooOol0ogoo
2Goo000EOol00`00Oomoo`3oOol9Ool001Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo
2Goo000?Oooo000A0001Ool001Eoo`8000Moo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo
00Ioo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo
00Ioo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo
00Ioo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo
00Ioo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo
00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo
00Eoo`03001oogoo00Eoo`8000Moo`005Goo0P00:Goo00<007ooOol0:7oo00<007ooOol0:7oo00<0
07ooOol0:Goo00<007ooOol0:7oo00<007ooOol09goo0P001goo000EOol00`00Ool0003nOol00`00
Oomoo`07Ool001Eoo`03001oo`000?ioo`03001oogoo00Moo`005Goo00@007ooOol00?aoo`03001o
ogoo00Qoo`005Goo0P0000=oo`00Ool0ngoo00<007ooOol027oo000EOol01@00Oomoogoo0000nWoo
00<007ooOol02Goo000EOol01@00Oomoogoo0000nWoo00<007ooOol02Goo000EOol00`00Oomoo`02
Ool00`00Oomoo`3fOol00`00Oomoo`0:Ool001Eoo`03001oogoo009oo`03001oogoo0?Ioo`03001o
ogoo00Yoo`005Goo00<007ooOol00goo00<007ooOol0m7oo00<007ooOol02goo000EOol00`00Oomo
o`03Ool00`00Oomoo`3dOol00`00Oomoo`0;Ool001Eoo`8000Eoo`03001oogoo0?9oo`03001oogoo
00aoo`005Goo00<007ooOol017oo00<007ooOol0lWoo00<007ooOol037oo000EOol00`00Oomoo`05
Ool00`00Oomoo`3`Ool00`00Oomoo`0=Ool001Eoo`03001oogoo00Eoo`03001oogoo0?1oo`03001o
ogoo00eoo`005Goo00<007ooOol01Woo00<007ooOol0kWoo00<007ooOol03Woo000EOol00`00Oomo
o`06Ool00`00Oomoo`3^Ool00`00Oomoo`0>Ool001Eoo`8000Qoo`03001oogoo0>aoo`03001oogoo
00moo`005Goo00<007ooOol027oo00<007ooOol0jWoo00<007ooOol047oo000EOol00`00Oomoo`08
Ool00`00Oomoo`3ZOol00`00Oomoo`0@Ool001Eoo`03001oogoo00Uoo`03001oogoo0>Qoo`03001o
ogoo015oo`005Goo00<007ooOol02Goo00<007ooOol0j7oo00<007ooOol04Goo000EOol00`00Oomo
o`0:Ool00`00Oomoo`3VOol00`00Oomoo`0BOol001Eoo`03001oogoo00Yoo`03001oogoo0>Ioo`03
001oogoo019oo`005Goo0P0037oo00<007ooOol0i7oo00<007ooOol04goo000EOol00`00Oomoo`0;
Ool00`00Oomoo`3TOol00`00Oomoo`0COol001Eoo`03001oogoo00aoo`03001oogoo0>9oo`03001o
ogoo01Aoo`005Goo00<007ooOol037oo00<007ooOol0hGoo00<007ooOol05Goo0002Ool20004Ool2
0003Ool50003Ool00`00Oomoo`0=Ool00`00Oomoo`3POol00`00Oomoo`0EOol00005Ool007ooOol0
000:Ool00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`3NOol00`00Oomoo`0FOol00005Ool0
07ooOol0000:Ool00`00Oomoo`03Ool3000>Ool00`00Oomoo`3NOol00`00Oomoo`0FOol00005Ool0
07ooOol0000:Ool00`00Oomoo`03Ool00`00Oomoo`0?Ool00`00Oomoo`3LOol00`00Oomoo`0GOol0
0005Ool007ooOol0000:Ool00`00Oomoo`03Ool00`00Oomoo`0?Ool00`00Oomoo`3LOol00`00Oomo
o`0GOol0009oo`8000Yoo`8000Eoo`03001oogoo011oo`03001oogoo0=Yoo`03001oogoo01Qoo`00
5Goo00<007ooOol047oo00<007ooOol0fWoo00<007ooOol067oo000EOol00`00Oomoo`0AOol00`00
Oomoo`3HOol00`00Oomoo`0IOol001Eoo`80019oo`03001oogoo0=Qoo`03001oogoo01Uoo`005Goo
00<007ooOol04Woo00<007ooOol0eWoo00<007ooOol06Woo000EOol00`00Oomoo`0BOol00`00Oomo
o`3EOol00`00Oomoo`0KOol001Eoo`03001oogoo01=oo`03001oogoo0=Aoo`03001oogoo01]oo`00
5Goo00<007ooOol057oo00<007ooOol0dWoo00<007ooOol077oo000EOol00`00Oomoo`0DOol00`00
Oomoo`3BOol00`00Oomoo`0LOol001Eoo`03001oogoo01Eoo`03001oogoo0=1oo`03001oogoo01eo
o`005Goo0P005Woo00<007ooOol0d7oo00<007ooOol07Goo000EOol00`00Oomoo`0FOol00`00Oomo
o`3>Ool00`00Oomoo`0NOol001Eoo`03001oogoo01Ioo`03001oogoo0<ioo`03001oogoo01ioo`00
5Goo00<007ooOol05goo00<007ooOol0c7oo00<007ooOol07goo000EOol00`00Oomoo`0GOol00`00
Oomoo`3;Ool00`00Oomoo`0POol001Eoo`03001oogoo01Qoo`03001oogoo0<Yoo`03001oogoo021o
o`005Goo0P006Woo00<007ooOol0b7oo00<007ooOol08Goo000EOol00`00Oomoo`0IOol00`00Oomo
o`38Ool00`00Oomoo`0QOol001Eoo`03001oogoo01Yoo`03001oogoo0<Ioo`03001oogoo029oo`00
5Goo00<007ooOol06Woo00<007ooOol0aWoo00<007ooOol08Woo000EOol00`00Oomoo`0KOol00`00
Oomoo`34Ool00`00Oomoo`0SOol001Eoo`03001oogoo01]oo`03001oogoo0<Aoo`03001oogoo02=o
o`005Goo00<007ooOol077oo00<007ooOol0`Woo00<007ooOol097oo000EOol2000MOol00`00Oomo
o`32Ool00`00Oomoo`0TOol001Eoo`03001oogoo01eoo`03001oogoo0<1oo`03001oogoo02Eoo`00
5Goo00<007ooOol07Goo00<007ooOol0_goo00<007ooOol09Woo000EOol00`00Oomoo`0NOol00`00
Oomoo`2nOol00`00Oomoo`0VOol0009oo`8000Aoo`8000=oo`@000Aoo`03001oogoo01moo`03001o
ogoo0;aoo`03001oogoo02Moo`0000Eoo`00Oomoo`0000Qoo`03001oogoo00Eoo`03001oogoo01mo
o`03001oogoo0;aoo`03001oogoo02Moo`0000Eoo`00Oomoo`0000Uoo`03001oogoo00Aoo`<0021o
o`03001oogoo0;Yoo`03001oogoo02Qoo`0000Eoo`00Oomoo`0000Yoo`03001oogoo00=oo`03001o
ogoo021oo`03001oogoo0;Yoo`03001oogoo02Qoo`0000Eoo`00Oomoo`0000Qoo`04001oogoo0004
Ool00`00Oomoo`0QOol00`00Oomoo`2hOol00`00Oomoo`0YOol0009oo`8000Yoo`8000Eoo`03001o
ogoo025oo`03001oogoo0;Qoo`03001oogoo02Uoo`005Goo00<007ooOol08Woo00<007ooOol0]Woo
00<007ooOol0:Woo000EOol00`00Oomoo`0ROol00`00Oomoo`2eOol00`00Oomoo`0[Ool001Eoo`80
02Aoo`03001oogoo0;Aoo`03001oogoo02]oo`005Goo00<007ooOol08goo00<007ooOol0/goo00<0
07ooOol0;7oo000EOol00`00Oomoo`0TOol00`00Oomoo`2bOol00`00Oomoo`0/Ool001Eoo`03001o
ogoo02Aoo`03001oogoo0;5oo`03001oogoo02eoo`005Goo00<007ooOol09Goo00<007ooOol0/7oo
00<007ooOol0;Goo000EOol00`00Oomoo`0UOol00`00Oomoo`2_Ool00`00Oomoo`0^Ool001Eoo`03
001oogoo02Ioo`03001oogoo0:ioo`03001oogoo02ioo`005Goo0P009goo00<007ooOol0[Goo00<0
07ooOol0;goo000EOol00`00Oomoo`0WOol00`00Oomoo`2/Ool00`00Oomoo`0_Ool001Eoo`03001o
ogoo02Moo`03001oogoo0:]oo`03001oogoo031oo`005Goo00<007ooOol0:7oo00<007ooOol0ZGoo
00<007ooOol0<Goo000EOol00`00Oomoo`0YOol00`00Oomoo`2XOol00`00Oomoo`0aOol001Eoo`03
001oogoo02Uoo`03001oogoo0:Moo`03001oogoo039oo`005Goo0P00:goo00<007ooOol0YWoo00<0
07ooOol0<Woo000EOol00`00Oomoo`0ZOol00`00Oomoo`2UOol00`00Oomoo`0cOol001Eoo`03001o
ogoo02]oo`03001oogoo0:Aoo`03001oogoo03=oo`005Goo00<007ooOol0:goo00<007ooOol0Xgoo
00<007ooOol0=7oo000EOol00`00Oomoo`0/Ool00`00Oomoo`2ROol00`00Oomoo`0dOol001Eoo`03
001oogoo02aoo`03001oogoo0:5oo`03001oogoo03Eoo`005Goo00<007ooOol0;Goo00<007ooOol0
X7oo00<007ooOol0=Goo000EOol2000_Ool00`00Oomoo`2NOol00`00Oomoo`0fOol001Eoo`03001o
ogoo02ioo`03001oogoo09ioo`03001oogoo03Ioo`005Goo00<007ooOol0;goo00<007ooOol0W7oo
00<007ooOol0=goo000EOol00`00Oomoo`0_Ool00`00Oomoo`2LOol00`00Oomoo`0gOol0009oo`80
00Aoo`8000Aoo`8000Eoo`03001oogoo031oo`03001oogoo09Yoo`03001oogoo03Qoo`0000Eoo`00
Oomoo`0000Qoo`04001oogoo0004Ool00`00Oomoo`0`Ool00`00Oomoo`2JOol00`00Oomoo`0hOol0
0005Ool007ooOol0000:Ool00`00Oomoo`03Ool3000aOol00`00Oomoo`2HOol00`00Oomoo`0iOol0
0005Ool007ooOol0000;Ool00`00Oomoo`02Ool00`00Oomoo`0aOol00`00Oomoo`2HOol00`00Oomo
o`0iOol00005Ool007ooOol00008Ool01000Oomoo`0017oo00<007ooOol0<Woo00<007ooOol0UWoo
00<007ooOol0>Woo0002Ool2000:Ool20005Ool00`00Oomoo`0bOol00`00Oomoo`2FOol00`00Oomo
o`0jOol001Eoo`03001oogoo03=oo`03001oogoo09Aoo`03001oogoo03]oo`005Goo00<007ooOol0
=7oo00<007ooOol0Tgoo00<007ooOol0>goo000EOol2000eOol00`00Oomoo`2BOol00`00Oomoo`0l
Ool001Eoo`03001oogoo03Eoo`03001oogoo095oo`03001oogoo03aoo`005Goo00<007ooOol0=Goo
00<007ooOol0T7oo00<007ooOol0?Goo000EOol00`00Oomoo`0fOol00`00Oomoo`2?Ool00`00Oomo
o`0mOol001Eoo`03001oogoo03Ioo`03001oogoo08ioo`03001oogoo03ioo`005Goo00<007ooOol0
=goo00<007ooOol0S7oo00<007ooOol0?goo000EOol00`00Oomoo`0gOol00`00Oomoo`2<Ool00`00
Oomoo`0oOol001Eoo`8003Uoo`03001oogoo08Yoo`03001oogoo041oo`005Goo00<007ooOol0>Goo
00<007ooOol0RGoo00<007ooOol0@7oo000EOol00`00Oomoo`0iOol00`00Oomoo`28Ool00`00Oomo
o`11Ool001Eoo`03001oogoo03Yoo`03001oogoo08Moo`03001oogoo045oo`005Goo00<007ooOol0
>Woo00<007ooOol0QWoo00<007ooOol0@Woo000EOol00`00Oomoo`0kOol00`00Oomoo`24Ool00`00
Oomoo`13Ool001Eoo`8003aoo`03001oogoo08Aoo`03001oogoo04=oo`005Goo00<007ooOol0?7oo
00<007ooOol0PWoo00<007ooOol0A7oo000EOol00`00Oomoo`0lOol00`00Oomoo`22Ool00`00Oomo
o`14Ool001Eoo`03001oogoo03eoo`03001oogoo081oo`03001oogoo04Eoo`005Goo00<007ooOol0
?Goo00<007ooOol0P7oo00<007ooOol0AGoo000EOol00`00Oomoo`0nOol00`00Oomoo`1nOol00`00
Oomoo`16Ool001Eoo`03001oogoo03moo`03001oogoo07aoo`03001oogoo04Moo`005Goo0P00@7oo
00<007ooOol0O7oo00<007ooOol0Agoo000EOol00`00Oomoo`10Ool00`00Oomoo`1jOol00`00Oomo
o`18Ool001Eoo`03001oogoo041oo`03001oogoo07Yoo`03001oogoo04Qoo`005Goo00<007ooOol0
@Goo00<007ooOol0N7oo00<007ooOol0BGoo0002Ool20004Ool20005Ool30003Ool00`00Oomoo`11
Ool00`00Oomoo`1hOol00`00Oomoo`19Ool00005Ool007ooOol0000;Ool00`00Oomoo`02Ool00`00
Oomoo`12Ool00`00Oomoo`1fOol00`00Oomoo`1:Ool00005Ool007ooOol00008Ool50003Ool30012
Ool00`00Oomoo`1fOol00`00Oomoo`1:Ool00005Ool007ooOol00008Ool01000Oomoo`0017oo00<0
07ooOol0@goo00<007ooOol0M7oo00<007ooOol0Bgoo00001Goo001oogoo00002Goo00<007oo0000
17oo00<007ooOol0@goo00<007ooOol0M7oo00<007ooOol0Bgoo0002Ool2000;Ool20004Ool00`00
Oomoo`14Ool00`00Oomoo`1bOol00`00Oomoo`1<Ool001Eoo`03001oogoo04Aoo`03001oogoo079o
o`03001oogoo04aoo`005Goo00<007ooOol0AGoo00<007ooOol0L7oo00<007ooOol0CGoo000EOol2
0016Ool00`00Oomoo`1`Ool00`00Oomoo`1=Ool001Eoo`03001oogoo04Ioo`03001oogoo06ioo`03
001oogoo04ioo`005Goo00<007ooOol0AWoo00<007ooOol0KWoo00<007ooOol0CWoo000EOol00`00
Oomoo`17Ool00`00Oomoo`1/Ool00`00Oomoo`1?Ool001Eoo`03001oogoo04Moo`03001oogoo06ao
o`03001oogoo04moo`005Goo00<007ooOol0B7oo00<007ooOol0JWoo00<007ooOol0D7oo000EOol0
0`00Oomoo`18Ool00`00Oomoo`1YOol00`00Oomoo`1AOol001Eoo`8004Yoo`03001oogoo06Qoo`03
001oogoo055oo`005Goo00<007ooOol0BWoo00<007ooOol0IWoo00<007ooOol0DWoo000EOol00`00
Oomoo`1:Ool00`00Oomoo`1VOol00`00Oomoo`1BOol001Eoo`03001oogoo04]oo`03001oogoo06Ao
o`03001oogoo05=oo`005Goo00<007ooOol0Bgoo00<007ooOol0I7oo00<007ooOol0Dgoo000EOol0
0`00Oomoo`1<Ool00`00Oomoo`1ROol00`00Oomoo`1DOol001Eoo`8004ioo`03001oogoo065oo`03
001oogoo05Aoo`005Goo00<007ooOol0CGoo00<007ooOol0H7oo00<007ooOol0EGoo000EOol00`00
Oomoo`1>Ool00`00Oomoo`1OOol00`00Oomoo`1EOol001Eoo`03001oogoo04ioo`03001oogoo05io
o`03001oogoo05Ioo`005Goo00<007ooOol0Cgoo00<007ooOol0GGoo00<007ooOol0EWoo000EOol0
0`00Oomoo`1?Ool00`00Oomoo`1LOol00`00Oomoo`1GOol001Eoo`03001oogoo051oo`03001oogoo
05]oo`03001oogoo05Moo`005Goo0P00DGoo00<007ooOol0FWoo00<007ooOol0F7oo000EOol00`00
Oomoo`1AOol00`00Oomoo`1IOol00`00Oomoo`1HOol001Eoo`03001oogoo055oo`03001oogoo05Qo
o`03001oogoo05Uoo`005Goo00<007ooOol0DWoo00<007ooOol0EWoo00<007ooOol0FWoo0002Ool2
0004Ool20004Ool20005Ool00`00Oomoo`1BOol00`00Oomoo`1EOol00`00Oomoo`1KOol00005Ool0
07ooOol00008Ool01000Oomoo`0017oo00<007ooOol0Dgoo00<007ooOol0E7oo00<007ooOol0Fgoo
00001Goo001oogoo00002goo00<007ooOol00Woo0`00DgooF000GGoo00001Goo001oogoo00002Goo
0P001Goo00<007ooOol0ogoo2Goo00001Goo001oogoo00002Goo00<007ooOol017oo00<007ooOol0
ogoo2Goo0002Ool2000:Ool30004Ool00`00Oomoo`3oOol9Ool001Eoo`03001oogoo0?moo`Uoo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.248956, -0.0387349, \
0.0115854, 0.00312425}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[7]="]
}, Open  ]],

Cell["\<\
Another ways of finding the convolution is to use Fourier transform and \
inverse Fourier transform. \
\>", "Text"],

Cell[BoxData[
    \(\({square1, square2} = {f[x], g[x]};\)\)], "Input",
  CellLabel->"In[8]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[{square1, square2}, {x, \(-1\), 3}]\)], "Input",
  CellLabel->"In[9]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.261905 0.238095 0.0147151 0.588604 [
[.02381 .00222 -6 -9 ]
[.02381 .00222 6 0 ]
[.5 .00222 -3 -9 ]
[.5 .00222 3 0 ]
[.7381 .00222 -3 -9 ]
[.7381 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.2494 .13244 -18 -4.5 ]
[.2494 .13244 0 4.5 ]
[.2494 .25016 -18 -4.5 ]
[.2494 .25016 0 4.5 ]
[.2494 .36788 -18 -4.5 ]
[.2494 .36788 0 4.5 ]
[.2494 .4856 -18 -4.5 ]
[.2494 .4856 0 4.5 ]
[.2494 .60332 -6 -4.5 ]
[.2494 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .02097 L
s
[(-1)] .02381 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(1)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(2)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(3)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.2619 .13244 m
.26815 .13244 L
s
[(0.2)] .2494 .13244 1 0 Mshowa
.2619 .25016 m
.26815 .25016 L
s
[(0.4)] .2494 .25016 1 0 Mshowa
.2619 .36788 m
.26815 .36788 L
s
[(0.6)] .2494 .36788 1 0 Mshowa
.2619 .4856 m
.26815 .4856 L
s
[(0.8)] .2494 .4856 1 0 Mshowa
.2619 .60332 m
.26815 .60332 L
s
[(1)] .2494 .60332 1 0 Mshowa
.125 Mabswid
.2619 .04415 m
.26565 .04415 L
s
.2619 .07358 m
.26565 .07358 L
s
.2619 .10301 m
.26565 .10301 L
s
.2619 .16187 m
.26565 .16187 L
s
.2619 .1913 m
.26565 .1913 L
s
.2619 .22073 m
.26565 .22073 L
s
.2619 .27959 m
.26565 .27959 L
s
.2619 .30902 m
.26565 .30902 L
s
.2619 .33845 m
.26565 .33845 L
s
.2619 .39731 m
.26565 .39731 L
s
.2619 .42674 m
.26565 .42674 L
s
.2619 .45617 m
.26565 .45617 L
s
.2619 .51503 m
.26565 .51503 L
s
.2619 .54446 m
.26565 .54446 L
s
.2619 .57389 m
.26565 .57389 L
s
.25 Mabswid
.2619 0 m
.2619 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .01472 L
.10458 .01472 L
.14415 .01472 L
.18221 .01472 L
.22272 .01472 L
.24141 .01472 L
.25127 .01472 L
.25666 .01472 L
.2593 .01472 L
.26045 .01472 L
.26171 .01472 L
.26301 .60332 L
.26425 .60332 L
.26698 .60332 L
.27279 .60332 L
.28302 .60332 L
.30316 .60332 L
.3438 .60332 L
.38293 .60332 L
.42451 .60332 L
.44538 .60332 L
.46458 .60332 L
.48333 .60332 L
.49277 .60332 L
.49535 .60332 L
.49678 .60332 L
.49813 .60332 L
.49938 .60332 L
.50009 .01472 L
.50074 .01472 L
.50313 .01472 L
.5424 .01472 L
.58015 .01472 L
.62035 .01472 L
.65904 .01472 L
.70018 .01472 L
.7398 .01472 L
.77791 .01472 L
.81847 .01472 L
.85752 .01472 L
.89901 .01472 L
.939 .01472 L
.97619 .01472 L
s
.02381 .01472 m
.06244 .01472 L
.10458 .01472 L
.14415 .01472 L
.18221 .01472 L
.22272 .01472 L
.24141 .01472 L
.25127 .01472 L
.25666 .01472 L
.2593 .01472 L
.26045 .01472 L
.26171 .01472 L
.26301 .30902 L
.26425 .30902 L
.26698 .30902 L
.27279 .30902 L
.28302 .30902 L
.30316 .30902 L
.3438 .30902 L
.38293 .30902 L
.42451 .30902 L
.46458 .30902 L
.50313 .30902 L
.54413 .30902 L
.58362 .30902 L
.62159 .30902 L
.66202 .30902 L
.70093 .30902 L
.7111 .30902 L
.72217 .30902 L
.72723 .30902 L
.73262 .30902 L
.73483 .30902 L
.73599 .30902 L
.73721 .30902 L
.73786 .30902 L
.73858 .01472 L
.73983 .01472 L
.74229 .01472 L
.78285 .01472 L
.82189 .01472 L
.86339 .01472 L
.90337 .01472 L
.94184 .01472 L
.97619 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[9]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo000?Ool5
001iOol5000lOol4000mOol2000?Ool0015oo`03001oogoo07]oo`03001oogoo03aoo`03001oogoo
03eoo`04001oogoo000>Ool0015oo`03001oogoo07]oo`03001oogoo03eoo`03001oogoo03ioo`03
001oogoo00eoo`002Goo100017oo00<007ooOol0Ngoo00<007ooOol0?Woo00<007ooOol0?Woo00<0
07ooOol037oo000AOol00`00Oomoo`1kOol00`00Oomoo`0lOol01000Oomoo`00?7oo00@007ooOol0
00ioo`0047oo0P00O7oo0P00?goo0P00?Woo0P003goo003oOolQOol004ioo`03001oogoo0<moo`00
CWoo00<007ooOol0cgoo001>Ool00`00Oomoo`3?Ool004ioo`03001oogoo0<moo`001gooo`004P00
27oo000>Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00
Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00
Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00
Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00
Oomoo`09Ool00`00Oomoo`0=Ool000ioo`03001oogoo03eoo`03001oogoo03ioo`03001oogoo03io
o`03001oogoo03eoo`03001oogoo00eoo`00CWoo00<007ooOol0?Woo00<007ooOol0?Woo00<007oo
Ool0CGoo001>Ool00`00Oomoo`0nOol00`00Oomoo`0nOol00`00Oomoo`1=Ool004ioo`03001oogoo
03ioo`03001oogoo03ioo`03001oogoo04eoo`00CWoo00<007ooOol0?Woo00<007ooOol0?Woo00<0
07ooOol0CGoo001>Ool00`00Oomoo`0nOol00`00Oomoo`0nOol00`00Oomoo`1=Ool004ioo`8003mo
o`03001oogoo03ioo`03001oogoo04eoo`00CWoo00<007ooOol0?Woo00<007ooOol0?Woo00<007oo
Ool0CGoo001>Ool00`00Oomoo`0nOol00`00Oomoo`0nOol00`00Oomoo`1=Ool004ioo`03001oogoo
03ioo`03001oogoo03ioo`03001oogoo04eoo`00CWoo00<007ooOol0?Woo00<007ooOol0?Woo00<0
07ooOol0CGoo001>Ool00`00Oomoo`0nOol00`00Oomoo`0nOol00`00Oomoo`1=Ool004ioo`03001o
ogoo03ioo`03001oogoo03ioo`03001oogoo04eoo`00CWoo00<007ooOol0?Woo00<007ooOol0?Woo
00<007ooOol0CGoo001>Ool2000oOol00`00Oomoo`0nOol00`00Oomoo`1=Ool004ioo`03001oogoo
03ioo`03001oogoo03ioo`03001oogoo04eoo`00CWoo00<007ooOol0?Woo00<007ooOol0?Woo00<0
07ooOol0CGoo001>Ool00`00Oomoo`0nOol00`00Oomoo`0nOol00`00Oomoo`1=Ool004ioo`03001o
ogoo03ioo`03001oogoo03ioo`03001oogoo04eoo`00CWoo00<007ooOol0?Woo00<007ooOol0?Woo
00<007ooOol0CGoo001>Ool00`00Oomoo`0nOol00`00Oomoo`0nOol00`00Oomoo`1=Ool004ioo`03
001oogoo03ioo`03001oogoo03ioo`03001oogoo04eoo`00CWoo0P00?goo00<007ooOol0?Woo00<0
07ooOol0CGoo001>Ool00`00Oomoo`0nOol00`00Oomoo`0nOol00`00Oomoo`1=Ool004ioo`03001o
ogoo03ioo`03001oogoo03ioo`03001oogoo04eoo`00CWoo00<007ooOol0?Woo00<007ooOol0?Woo
00<007ooOol0CGoo001>Ool00`00Oomoo`0nOol00`00Oomoo`0nOol00`00Oomoo`1=Ool004ioo`03
001oogoo03ioo`03001oogoo03ioo`03001oogoo04eoo`00>goo0P0017oo0P000goo100017oo00<0
07ooOol0?Woo00<007ooOol0?Woo00<007ooOol0CGoo000jOol01000Oomoo`0027oo00<007ooOol0
1Goo00<007ooOol0?Woo00<007ooOol0?Woo00<007ooOol0CGoo000jOol01000Oomoo`002Goo00<0
07ooOol017oo0`00?Woo00<007ooOol0?Woo00<007ooOol0CGoo000jOol01000Oomoo`002Woo00<0
07ooOol00goo00<007ooOol0?Woo00<007ooOol0?Woo00<007ooOol0CGoo000jOol01000Oomoo`00
27oo00@007ooOol000Aoo`03001oogoo03ioo`03001oogoo03ioo`03001oogoo04eoo`00>goo0P00
2Woo0P001Goo00<007ooOol0?Woo00<007ooOol0?Woo00<007ooOol0CGoo001>Ool00`00Oomoo`0n
Ool00`00Oomoo`0nOol00`00Oomoo`1=Ool004ioo`03001oogoo03ioo`03001oogoo03ioo`03001o
ogoo04eoo`00CWoo00<007ooOol0?Woo00<007ooOol0?Woo00<007ooOol0CGoo001>Ool00`00Oomo
o`0nOol00`00Oomoo`0nOol00`00Oomoo`1=Ool004ioo`8003moo`03001oogoo03ioo`03001oogoo
04eoo`00CWoo0P00?goo00<007ooOol0?Woo00<007ooOol0CGoo001>Ool2000oOol00`00Oomoo`0n
Ool00`00Oomoo`1=Ool004ioo`8003moo`03001oogoo03ioo`03001oogoo04eoo`00CWoo0P00?goo
00<007ooOol0?Woo00<007ooOol0CGoo001>Ool2000oOol00`00Oomoo`0nOol00`00Oomoo`1=Ool0
04ioo`8003moo`03001oogoo03ioo`03001oogoo04eoo`00CWoo0P00?goo00<007ooOol0?Woo00<0
07ooOol0CGoo001>Ool2000oOol00`00Oomoo`0nOol00`00Oomoo`1=Ool004ioo`8003moo`03001o
ogoo03ioo`03001oogoo04eoo`00CWoo0P00?goo00<007ooOol0?Woo00<007ooOol0CGoo001>Ool2
000oOol00`00Oomoo`0nOol00`00Oomoo`1=Ool004ioo`8003moo`03001oogoo03ioo`03001oogoo
04eoo`00CWoo0P00?goo00<007ooOol0?Woo00<007ooOol0CGoo001>Ool2000oOol00`00Oomoo`0n
Ool00`00Oomoo`1=Ool004ioo`8003moo`03001oogoo03ioo`03001oogoo04eoo`00CWoo0P00?goo
00<007ooOol0?Woo00<007ooOol0CGoo001>Ool2000oOol00`00Oomoo`0nOol00`00Oomoo`1=Ool0
04ioo`8003moo`03001oogoo03ioo`03001oogoo04eoo`00CWoo0P00?goo00<007ooOol0?Woo00<0
07ooOol0CGoo001>Ool2000oOol00`00Oomoo`0nOol00`00Oomoo`1=Ool004ioo`8003moo`03001o
ogoo03ioo`03001oogoo04eoo`00>goo0P0017oo0P001Goo0`000goo0P00?goo00<007ooOol0?Woo
00<007ooOol0CGoo000jOol01000Oomoo`002goo00<007ooOol00Woo0P00?goo00<007ooOol0?Woo
00<007ooOol0CGoo000jOol01000Oomoo`0027oo1@000goo0`00?Woo00<007ooOol0?Woo00<007oo
Ool0CGoo000jOol01000Oomoo`0027oo00@007ooOol000Aoo`8003moo`03001oogoo03ioo`03001o
ogoo04eoo`00>Woo00@007ooOol000Uoo`03001oo`0000Aoo`8003moo`03001oogoo03ioo`03001o
ogoo04eoo`00>goo0P002goo0P0017oo0P00?goo00<007ooOol0?Woo00<007ooOol0CGoo001>Ool2
000oOol00`00Oomoo`0nOol00`00Oomoo`1=Ool004ioo`8003moo`03001oogoo03ioo`03001oogoo
04eoo`00CWoo0P00?goo00<007ooOol0?Woo00<007ooOol0CGoo001>Ool2000oOol00`00Oomoo`0n
Ool00`00Oomoo`1=Ool004ioo`8003moo`03001oogoo03ioo`03001oogoo04eoo`00CWoo0P00?goo
00<007ooOol0?Woo00<007ooOol0CGoo001>Ool2000oOol00`00Oomoo`0nOol00`00Oomoo`1=Ool0
04ioo`8003moo`03001oogoo03ioo`03001oogoo04eoo`00CWoo0P00?goo00<007ooOol0?Woo00<0
07ooOol0CGoo001>Ool2000oOol00`00Oomoo`0nOol00`00Oomoo`1=Ool004ioo`8003moo`03001o
ogoo03ioo`03001oogoo04eoo`00CWoo0P00?goo00<007ooOol0?Woo00<007ooOol0CGoo001>Oon3
001?Ool004ioo`8003moo`03001oogoo08ioo`00CWoo0P00?goo00<007ooOol0SWoo001>Ool2000o
Ool00`00Oomoo`2>Ool004ioo`8003moo`03001oogoo08ioo`00CWoo0P00?goo00<007ooOol0SWoo
001>Ool2000oOol00`00Oomoo`2>Ool004ioo`8003moo`03001oogoo08ioo`00CWoo0P00?goo00<0
07ooOol0SWoo001>Ool2000oOol00`00Oomoo`2>Ool004ioo`8003moo`03001oogoo08ioo`00CWoo
0P00?goo00<007ooOol0SWoo001>Ool2000oOol00`00Oomoo`2>Ool004ioo`8003moo`03001oogoo
08ioo`00>goo0P0017oo0P000goo0`001Goo0P00?goo00<007ooOol0SWoo000jOol01000Oomoo`00
27oo00@007ooOol000Aoo`8003moo`03001oogoo08ioo`00>Woo00@007ooOol000Qoo`04001oogoo
0004Ool3000nOol00`00Oomoo`2>Ool003Yoo`04001oogoo0008Ool30005Ool2000oOol00`00Oomo
o`2>Ool003Yoo`04001oogoo0009Ool00`00Oomoo`04Ool2000oOol00`00Oomoo`2>Ool003]oo`80
00Yoo`<000Aoo`8003moo`03001oogoo08ioo`00CWoo0P00?goo00<007ooOol0SWoo001>Ool2000o
Ool00`00Oomoo`2>Ool004ioo`8003moo`03001oogoo08ioo`00CWoo0P00?goo00<007ooOol0SWoo
001>Ool2000oOol00`00Oomoo`2>Ool004ioo`8003moo`03001oogoo08ioo`00CWoo0P00?goo00<0
07ooOol0SWoo001>Ool2000oOol00`00Oomoo`2>Ool004ioo`8003moo`03001oogoo08ioo`00CWoo
0P00?goo00<007ooOol0SWoo001>Ool2000oOol00`00Oomoo`2>Ool004ioo`8003moo`03001oogoo
08ioo`00CWoo0P00?goo00<007ooOol0SWoo001>Ool2000oOol00`00Oomoo`2>Ool004ioo`8003mo
o`03001oogoo08ioo`00CWoo0P00?goo00<007ooOol0SWoo001>Ool2000oOol00`00Oomoo`2>Ool0
04ioo`8003moo`03001oogoo08ioo`00CWoo0P00?goo00<007ooOol0SWoo001>Ool2000oOol00`00
Oomoo`2>Ool004ioo`8003moo`03001oogoo08ioo`00CWoo0P00?goo00<007ooOol0SWoo001>Ool2
000oOol00`00Oomoo`2>Ool004ioo`8003moo`03001oogoo08ioo`00CWoo0P00?goo00<007ooOol0
SWoo001>Ool2000oOol00`00Oomoo`2>Ool003]oo`8000Aoo`8000Aoo`8000Eoo`8003moo`03001o
ogoo08ioo`00>Woo00@007ooOol000Qoo`04001oogoo0004Ool2000oOol00`00Oomoo`2>Ool003Yo
o`04001oogoo0008Ool01000Oomoo`0017oo0`00?Woo00<007ooOol0SWoo000jOol01000Oomoo`00
2Goo0P001Goo0P00?goo00<007ooOol0SWoo000jOol01000Oomoo`0027oo00@007ooOol000Aoo`80
03moo`03001oogoo08ioo`00>goo0P002Woo0P001Goo0P00?goo00<007ooOol0SWoo001>Ool2000o
Ool00`00Oomoo`2>Ool004ioo`8003moo`03001oogoo08ioo`00CWoo0P00?goo00<007ooOol0SWoo
001>Ool2000oOol00`00Oomoo`2>Ool004ioo`8003moo`03001oogoo08ioo`00CWoo0P00?goo00<0
07ooOol0SWoo001>Ool2000oOol00`00Oomoo`2>Ool004ioo`8003moo`03001oogoo08ioo`00CWoo
0P00?goo00<007ooOol0SWoo001>Ool2000oOol00`00Oomoo`2>Ool004ioo`8003moo`03001oogoo
08ioo`00CWoo0P00?goo00<007ooOol0SWoo001>Ool2000oOol00`00Oomoo`2>Ool004ioo`8003mo
o`03001oogoo08ioo`00CWoo0P00?goo00<007ooOol0SWoo001>Ool2000oOol00`00Oomoo`2>Ool0
04ioo`8003moo`03001oogoo08ioo`00CWoo0P00?goo00<007ooOol0SWoo001>Ool2000oOol00`00
Oomoo`2>Ool004ioo`8003moo`03001oogoo08ioo`00CWoo0P00?goo00<007ooOol0SWoo001>Ool2
000oOol00`00Oomoo`2>Ool004ioo`8003moo`03001oogoo08ioo`00CWoo0P00?goo00<007ooOol0
SWoo001>Ool2000oOol00`00Oomoo`2>Ool004ioo`8003moo`03001oogoo08ioo`00AWoo1@000goo
0P00?goo00<007ooOol0SWoo0018Ool00`00Oomoo`03Ool2000oOol00`00Oomoo`2>Ool004Qoo`03
001oogoo00=ood80091oo`00B7oo00<007ooOol00goo00<007ooOol0cgoo0018Ool00`00Oomoo`03
Ool00`00Oomoo`3?Ool004Moo`8000Eoo`03001oogoo0<moo`00CWoo00<007ooOol0cgoo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.21667, -0.07747, \
0.0154472, 0.00624851}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[9]="]
}, Open  ]],

Cell["Find the Fourier transform of both PDFs. ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ft1 = FourierTransform[square1, x, w]\)], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    \(\(-\(\(\[ImaginaryI]\ \((\(-1\) + \[ExponentialE]\^\(\[ImaginaryI]\ \
w\))\)\)\/\(\@\(2\ \[Pi]\)\ w\)\)\)\)], "Output",
  CellLabel->"Out[10]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ft2 = FourierTransform[square2, x, w]\)], "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[
    \(\(-\(\(\[ImaginaryI]\ \((\(-1\) + \[ExponentialE]\^\(2\ \[ImaginaryI]\ \
w\))\)\)\/\(2\ \@\(2\ \[Pi]\)\ w\)\)\)\)], "Output",
  CellLabel->"Out[11]="]
}, Open  ]],

Cell["\<\
Find the Inverse Fourier transform of both PDFs to obtain convolution of both \
PDFs. \
\>", "Text"],

Cell[BoxData[
    \(\(\(\@\(2  \[Pi]\)\) ft1\ ft2 // Expand;\)\)], "Input",
  CellLabel->"In[12]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(invft = \(InverseFourierTransform[#, w, x] &\)\  /@ \ %\)], "Input",
  CellLabel->"In[13]:="],

Cell[BoxData[
    \(1\/4\ \((\(-3\) + x)\)\ Sign[\(-3\) + x] - 
      1\/4\ \((\(-2\) + x)\)\ Sign[\(-2\) + x] - 
      1\/4\ \((\(-1\) + x)\)\ Sign[\(-1\) + x] + 1\/4\ x\ Sign[x]\)], "Output",\

  CellLabel->"Out[13]="]
}, Open  ]],

Cell["Now the plot of the PDF of Z(=X+Y). ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[invft, {x, 0, 3}]\)], "Input",
  CellLabel->"In[14]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.0147151 1.17721 [
[.18254 .00222 -9 -9 ]
[.18254 .00222 9 0 ]
[.34127 .00222 -3 -9 ]
[.34127 .00222 3 0 ]
[.5 .00222 -9 -9 ]
[.5 .00222 9 0 ]
[.65873 .00222 -3 -9 ]
[.65873 .00222 3 0 ]
[.81746 .00222 -9 -9 ]
[.81746 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .13244 -18 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .25016 -18 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .36788 -18 -4.5 ]
[.01131 .36788 0 4.5 ]
[.01131 .4856 -18 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .60332 -18 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .01472 m
.18254 .02097 L
s
[(0.5)] .18254 .00222 0 1 Mshowa
.34127 .01472 m
.34127 .02097 L
s
[(1)] .34127 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(1.5)] .5 .00222 0 1 Mshowa
.65873 .01472 m
.65873 .02097 L
s
[(2)] .65873 .00222 0 1 Mshowa
.81746 .01472 m
.81746 .02097 L
s
[(2.5)] .81746 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(3)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.05556 .01472 m
.05556 .01847 L
s
.0873 .01472 m
.0873 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.15079 .01472 m
.15079 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.24603 .01472 m
.24603 .01847 L
s
.27778 .01472 m
.27778 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.37302 .01472 m
.37302 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.43651 .01472 m
.43651 .01847 L
s
.46825 .01472 m
.46825 .01847 L
s
.53175 .01472 m
.53175 .01847 L
s
.56349 .01472 m
.56349 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62698 .01472 m
.62698 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.72222 .01472 m
.72222 .01847 L
s
.75397 .01472 m
.75397 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.84921 .01472 m
.84921 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.9127 .01472 m
.9127 .01847 L
s
.94444 .01472 m
.94444 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13244 m
.03006 .13244 L
s
[(0.1)] .01131 .13244 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(0.2)] .01131 .25016 1 0 Mshowa
.02381 .36788 m
.03006 .36788 L
s
[(0.3)] .01131 .36788 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(0.4)] .01131 .4856 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(0.5)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .03826 m
.02756 .03826 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .08535 m
.02756 .08535 L
s
.02381 .10889 m
.02756 .10889 L
s
.02381 .15598 m
.02756 .15598 L
s
.02381 .17952 m
.02756 .17952 L
s
.02381 .20307 m
.02756 .20307 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .2737 m
.02756 .2737 L
s
.02381 .29724 m
.02756 .29724 L
s
.02381 .32079 m
.02756 .32079 L
s
.02381 .34433 m
.02756 .34433 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .41497 m
.02756 .41497 L
s
.02381 .43851 m
.02756 .43851 L
s
.02381 .46205 m
.02756 .46205 L
s
.02381 .50914 m
.02756 .50914 L
s
.02381 .53269 m
.02756 .53269 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57977 m
.02756 .57977 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .08635 L
.10458 .16447 L
.14415 .23784 L
.18221 .3084 L
.22272 .38351 L
.26171 .45581 L
.30316 .53265 L
.32392 .57115 L
.33304 .58806 L
.33788 .59703 L
.33927 .59962 L
.33996 .60089 L
.3406 .60207 L
.34179 .60332 L
.34309 .60332 L
.35271 .60332 L
.36173 .60332 L
.3815 .60332 L
.42063 .60332 L
.46221 .60332 L
.50228 .60332 L
.54083 .60332 L
.58183 .60332 L
.60225 .60332 L
.62132 .60332 L
.63965 .60332 L
.64492 .60332 L
.64992 .60332 L
.65441 .60332 L
.65564 .60332 L
.65694 .60332 L
.65806 .60332 L
.65929 .60228 L
.66051 .60002 L
.66164 .59793 L
.66421 .59316 L
.66938 .58357 L
.67864 .56641 L
.69949 .52774 L
.73854 .45535 L
.78004 .3784 L
.82002 .30427 L
.85849 .23295 L
.8994 .15709 L
.93881 .08403 L
.97619 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[14]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo000iOol2
0004Ool20004Ool2000ROol5000POol50002Ool20004Ool2000SOol4000QOol40003Ool20004Ool2
000SOol20007Ool003Qoo`04001oogoo0008Ool01000Oomoo`008goo00<007ooOol08Woo00<007oo
Ool01goo00@007ooOol0029oo`03001oogoo029oo`03001oogoo00Uoo`04001oogoo000QOol01000
Oomoo`001Woo000hOol01000Oomoo`002goo00<007ooOol08Goo00<007ooOol08Woo00<007ooOol0
2Woo00<007ooOol08Goo00<007ooOol08Woo00<007ooOol02goo00<007ooOol08Goo00<007ooOol0
1Goo000hOol01000Oomoo`002Goo0P0097oo00<007ooOol08Woo00<007ooOol027oo0P009Goo00<0
07ooOol08Woo00<007ooOol027oo0P009Goo00<007ooOol017oo000hOol01000Oomoo`002Goo00<0
07ooOol08goo00<007ooOol08Woo00<007ooOol027oo00<007ooOol08Woo00@007ooOol0025oo`04
001oogoo0009Ool00`00Oomoo`0QOol01000Oomoo`001Woo000iOol2000:Ool3000ROol2000SOol2
000:Ool3000SOol2000SOol2000:Ool3000ROol20007Ool00?moob5oo`005Goo00<007ooOol0ogoo
2Goo000EOol00`00Oomoo`3oOol9Ool001Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo
2Goo000?Oooo000A0001Ool001Eoo`8000Moo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo
00Ioo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo
00Ioo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo
00Ioo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo
00Ioo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo
00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo
00Eoo`03001oogoo00Eoo`8000Moo`005Goo0P00:Goo00<007ooOol0:7oo00<007ooOol0:7oo00<0
07ooOol0:Goo00<007ooOol0:7oo00<007ooOol09goo0P001goo000EOol00`00Ool0003nOol00`00
Oomoo`07Ool001Eoo`03001oo`000?ioo`03001oogoo00Moo`005Goo00@007ooOol00?aoo`03001o
ogoo00Qoo`005Goo0P0000=oo`00Ool0ngoo00<007ooOol027oo000EOol01@00Oomoogoo0000nWoo
00<007ooOol02Goo000EOol01@00Oomoogoo0000nWoo00<007ooOol02Goo000EOol00`00Oomoo`02
Ool00`00Oomoo`3fOol00`00Oomoo`0:Ool001Eoo`03001oogoo009oo`03001oogoo0?Ioo`03001o
ogoo00Yoo`005Goo00<007ooOol00goo00<007ooOol0m7oo00<007ooOol02goo000EOol00`00Oomo
o`03Ool00`00Oomoo`3dOol00`00Oomoo`0;Ool001Eoo`8000Eoo`03001oogoo0?9oo`03001oogoo
00aoo`005Goo00<007ooOol017oo00<007ooOol0lWoo00<007ooOol037oo000EOol00`00Oomoo`05
Ool00`00Oomoo`3`Ool00`00Oomoo`0=Ool001Eoo`03001oogoo00Eoo`03001oogoo0?1oo`03001o
ogoo00eoo`005Goo00<007ooOol01Woo00<007ooOol0kWoo00<007ooOol03Woo000EOol00`00Oomo
o`06Ool00`00Oomoo`3^Ool00`00Oomoo`0>Ool001Eoo`8000Qoo`03001oogoo0>aoo`03001oogoo
00moo`005Goo00<007ooOol027oo00<007ooOol0jWoo00<007ooOol047oo000EOol00`00Oomoo`08
Ool00`00Oomoo`3ZOol00`00Oomoo`0@Ool001Eoo`03001oogoo00Uoo`03001oogoo0>Qoo`03001o
ogoo015oo`005Goo00<007ooOol02Goo00<007ooOol0j7oo00<007ooOol04Goo000EOol00`00Oomo
o`0:Ool00`00Oomoo`3VOol00`00Oomoo`0BOol001Eoo`03001oogoo00Yoo`03001oogoo0>Ioo`03
001oogoo019oo`005Goo0P0037oo00<007ooOol0i7oo00<007ooOol04goo000EOol00`00Oomoo`0;
Ool00`00Oomoo`3TOol00`00Oomoo`0COol001Eoo`03001oogoo00aoo`03001oogoo0>9oo`03001o
ogoo01Aoo`005Goo00<007ooOol037oo00<007ooOol0hGoo00<007ooOol05Goo0002Ool20004Ool2
0003Ool50003Ool00`00Oomoo`0=Ool00`00Oomoo`3POol00`00Oomoo`0EOol00005Ool007ooOol0
000:Ool00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`3NOol00`00Oomoo`0FOol00005Ool0
07ooOol0000:Ool00`00Oomoo`03Ool3000>Ool00`00Oomoo`3NOol00`00Oomoo`0FOol00005Ool0
07ooOol0000:Ool00`00Oomoo`03Ool00`00Oomoo`0?Ool00`00Oomoo`3LOol00`00Oomoo`0GOol0
0005Ool007ooOol0000:Ool00`00Oomoo`03Ool00`00Oomoo`0?Ool00`00Oomoo`3LOol00`00Oomo
o`0GOol0009oo`8000Yoo`8000Eoo`03001oogoo011oo`03001oogoo0=Yoo`03001oogoo01Qoo`00
5Goo00<007ooOol047oo00<007ooOol0fWoo00<007ooOol067oo000EOol00`00Oomoo`0AOol00`00
Oomoo`3HOol00`00Oomoo`0IOol001Eoo`80019oo`03001oogoo0=Qoo`03001oogoo01Uoo`005Goo
00<007ooOol04Woo00<007ooOol0eWoo00<007ooOol06Woo000EOol00`00Oomoo`0BOol00`00Oomo
o`3EOol00`00Oomoo`0KOol001Eoo`03001oogoo01=oo`03001oogoo0=Aoo`03001oogoo01]oo`00
5Goo00<007ooOol057oo00<007ooOol0dWoo00<007ooOol077oo000EOol00`00Oomoo`0DOol00`00
Oomoo`3BOol00`00Oomoo`0LOol001Eoo`03001oogoo01Eoo`03001oogoo0=1oo`03001oogoo01eo
o`005Goo0P005Woo00<007ooOol0d7oo00<007ooOol07Goo000EOol00`00Oomoo`0FOol00`00Oomo
o`3>Ool00`00Oomoo`0NOol001Eoo`03001oogoo01Ioo`03001oogoo0<ioo`03001oogoo01ioo`00
5Goo00<007ooOol05goo00<007ooOol0c7oo00<007ooOol07goo000EOol00`00Oomoo`0GOol00`00
Oomoo`3;Ool00`00Oomoo`0POol001Eoo`03001oogoo01Qoo`03001oogoo0<Yoo`03001oogoo021o
o`005Goo0P006Woo00<007ooOol0b7oo00<007ooOol08Goo000EOol00`00Oomoo`0IOol00`00Oomo
o`38Ool00`00Oomoo`0QOol001Eoo`03001oogoo01Yoo`03001oogoo0<Ioo`03001oogoo029oo`00
5Goo00<007ooOol06Woo00<007ooOol0aWoo00<007ooOol08Woo000EOol00`00Oomoo`0KOol00`00
Oomoo`34Ool00`00Oomoo`0SOol001Eoo`03001oogoo01]oo`03001oogoo0<Aoo`03001oogoo02=o
o`005Goo00<007ooOol077oo00<007ooOol0`Woo00<007ooOol097oo000EOol2000MOol00`00Oomo
o`32Ool00`00Oomoo`0TOol001Eoo`03001oogoo01eoo`03001oogoo0<1oo`03001oogoo02Eoo`00
5Goo00<007ooOol07Goo00<007ooOol0_goo00<007ooOol09Woo000EOol00`00Oomoo`0NOol00`00
Oomoo`2nOol00`00Oomoo`0VOol0009oo`8000Aoo`8000=oo`@000Aoo`03001oogoo01moo`03001o
ogoo0;aoo`03001oogoo02Moo`0000Eoo`00Oomoo`0000Qoo`03001oogoo00Eoo`03001oogoo01mo
o`03001oogoo0;aoo`03001oogoo02Moo`0000Eoo`00Oomoo`0000Uoo`03001oogoo00Aoo`<0021o
o`03001oogoo0;Yoo`03001oogoo02Qoo`0000Eoo`00Oomoo`0000Yoo`03001oogoo00=oo`03001o
ogoo021oo`03001oogoo0;Yoo`03001oogoo02Qoo`0000Eoo`00Oomoo`0000Qoo`04001oogoo0004
Ool00`00Oomoo`0QOol00`00Oomoo`2hOol00`00Oomoo`0YOol0009oo`8000Yoo`8000Eoo`03001o
ogoo025oo`03001oogoo0;Qoo`03001oogoo02Uoo`005Goo00<007ooOol08Woo00<007ooOol0]Woo
00<007ooOol0:Woo000EOol00`00Oomoo`0ROol00`00Oomoo`2eOol00`00Oomoo`0[Ool001Eoo`80
02Aoo`03001oogoo0;Aoo`03001oogoo02]oo`005Goo00<007ooOol08goo00<007ooOol0/goo00<0
07ooOol0;7oo000EOol00`00Oomoo`0TOol00`00Oomoo`2bOol00`00Oomoo`0/Ool001Eoo`03001o
ogoo02Aoo`03001oogoo0;5oo`03001oogoo02eoo`005Goo00<007ooOol09Goo00<007ooOol0/7oo
00<007ooOol0;Goo000EOol00`00Oomoo`0UOol00`00Oomoo`2_Ool00`00Oomoo`0^Ool001Eoo`03
001oogoo02Ioo`03001oogoo0:ioo`03001oogoo02ioo`005Goo0P009goo00<007ooOol0[Goo00<0
07ooOol0;goo000EOol00`00Oomoo`0WOol00`00Oomoo`2/Ool00`00Oomoo`0_Ool001Eoo`03001o
ogoo02Moo`03001oogoo0:]oo`03001oogoo031oo`005Goo00<007ooOol0:7oo00<007ooOol0ZGoo
00<007ooOol0<Goo000EOol00`00Oomoo`0YOol00`00Oomoo`2XOol00`00Oomoo`0aOol001Eoo`03
001oogoo02Uoo`03001oogoo0:Moo`03001oogoo039oo`005Goo0P00:goo00<007ooOol0YWoo00<0
07ooOol0<Woo000EOol00`00Oomoo`0ZOol00`00Oomoo`2UOol00`00Oomoo`0cOol001Eoo`03001o
ogoo02]oo`03001oogoo0:Aoo`03001oogoo03=oo`005Goo00<007ooOol0:goo00<007ooOol0Xgoo
00<007ooOol0=7oo000EOol00`00Oomoo`0/Ool00`00Oomoo`2ROol00`00Oomoo`0dOol001Eoo`03
001oogoo02aoo`03001oogoo0:5oo`03001oogoo03Eoo`005Goo00<007ooOol0;Goo00<007ooOol0
X7oo00<007ooOol0=Goo000EOol2000_Ool00`00Oomoo`2NOol00`00Oomoo`0fOol001Eoo`03001o
ogoo02ioo`03001oogoo09ioo`03001oogoo03Ioo`005Goo00<007ooOol0;goo00<007ooOol0W7oo
00<007ooOol0=goo000EOol00`00Oomoo`0_Ool00`00Oomoo`2LOol00`00Oomoo`0gOol0009oo`80
00Aoo`8000Aoo`8000Eoo`03001oogoo031oo`03001oogoo09Yoo`03001oogoo03Qoo`0000Eoo`00
Oomoo`0000Qoo`04001oogoo0004Ool00`00Oomoo`0`Ool00`00Oomoo`2JOol00`00Oomoo`0hOol0
0005Ool007ooOol0000:Ool00`00Oomoo`03Ool3000aOol00`00Oomoo`2HOol00`00Oomoo`0iOol0
0005Ool007ooOol0000;Ool00`00Oomoo`02Ool00`00Oomoo`0aOol00`00Oomoo`2HOol00`00Oomo
o`0iOol00005Ool007ooOol00008Ool01000Oomoo`0017oo00<007ooOol0<Woo00<007ooOol0UWoo
00<007ooOol0>Woo0002Ool2000:Ool20005Ool00`00Oomoo`0bOol00`00Oomoo`2FOol00`00Oomo
o`0jOol001Eoo`03001oogoo03=oo`03001oogoo09Aoo`03001oogoo03]oo`005Goo00<007ooOol0
=7oo00<007ooOol0Tgoo00<007ooOol0>goo000EOol2000eOol00`00Oomoo`2BOol00`00Oomoo`0l
Ool001Eoo`03001oogoo03Eoo`03001oogoo095oo`03001oogoo03aoo`005Goo00<007ooOol0=Goo
00<007ooOol0T7oo00<007ooOol0?Goo000EOol00`00Oomoo`0fOol00`00Oomoo`2?Ool00`00Oomo
o`0mOol001Eoo`03001oogoo03Ioo`03001oogoo08ioo`03001oogoo03ioo`005Goo00<007ooOol0
=goo00<007ooOol0S7oo00<007ooOol0?goo000EOol00`00Oomoo`0gOol00`00Oomoo`2<Ool00`00
Oomoo`0oOol001Eoo`8003Uoo`03001oogoo08Yoo`03001oogoo041oo`005Goo00<007ooOol0>Goo
00<007ooOol0RGoo00<007ooOol0@7oo000EOol00`00Oomoo`0iOol00`00Oomoo`28Ool00`00Oomo
o`11Ool001Eoo`03001oogoo03Yoo`03001oogoo08Moo`03001oogoo045oo`005Goo00<007ooOol0
>Woo00<007ooOol0QWoo00<007ooOol0@Woo000EOol00`00Oomoo`0kOol00`00Oomoo`24Ool00`00
Oomoo`13Ool001Eoo`8003aoo`03001oogoo08Aoo`03001oogoo04=oo`005Goo00<007ooOol0?7oo
00<007ooOol0PWoo00<007ooOol0A7oo000EOol00`00Oomoo`0lOol00`00Oomoo`22Ool00`00Oomo
o`14Ool001Eoo`03001oogoo03eoo`03001oogoo081oo`03001oogoo04Eoo`005Goo00<007ooOol0
?Goo00<007ooOol0P7oo00<007ooOol0AGoo000EOol00`00Oomoo`0nOol00`00Oomoo`1nOol00`00
Oomoo`16Ool001Eoo`03001oogoo03moo`03001oogoo07aoo`03001oogoo04Moo`005Goo0P00@7oo
00<007ooOol0O7oo00<007ooOol0Agoo000EOol00`00Oomoo`10Ool00`00Oomoo`1jOol00`00Oomo
o`18Ool001Eoo`03001oogoo041oo`03001oogoo07Yoo`03001oogoo04Qoo`005Goo00<007ooOol0
@Goo00<007ooOol0N7oo00<007ooOol0BGoo0002Ool20004Ool20005Ool30003Ool00`00Oomoo`11
Ool00`00Oomoo`1hOol00`00Oomoo`19Ool00005Ool007ooOol0000;Ool00`00Oomoo`02Ool00`00
Oomoo`12Ool00`00Oomoo`1fOol00`00Oomoo`1:Ool00005Ool007ooOol00008Ool50003Ool30012
Ool00`00Oomoo`1fOol00`00Oomoo`1:Ool00005Ool007ooOol00008Ool01000Oomoo`0017oo00<0
07ooOol0@goo00<007ooOol0M7oo00<007ooOol0Bgoo00001Goo001oogoo00002Goo00<007oo0000
17oo00<007ooOol0@goo00<007ooOol0M7oo00<007ooOol0Bgoo0002Ool2000;Ool20004Ool00`00
Oomoo`14Ool00`00Oomoo`1bOol00`00Oomoo`1<Ool001Eoo`03001oogoo04Aoo`03001oogoo079o
o`03001oogoo04aoo`005Goo00<007ooOol0AGoo00<007ooOol0L7oo00<007ooOol0CGoo000EOol2
0016Ool00`00Oomoo`1`Ool00`00Oomoo`1=Ool001Eoo`03001oogoo04Ioo`03001oogoo06ioo`03
001oogoo04ioo`005Goo00<007ooOol0AWoo00<007ooOol0KWoo00<007ooOol0CWoo000EOol00`00
Oomoo`17Ool00`00Oomoo`1/Ool00`00Oomoo`1?Ool001Eoo`03001oogoo04Moo`03001oogoo06ao
o`03001oogoo04moo`005Goo00<007ooOol0B7oo00<007ooOol0JWoo00<007ooOol0D7oo000EOol0
0`00Oomoo`18Ool00`00Oomoo`1YOol00`00Oomoo`1AOol001Eoo`8004Yoo`03001oogoo06Qoo`03
001oogoo055oo`005Goo00<007ooOol0BWoo00<007ooOol0IWoo00<007ooOol0DWoo000EOol00`00
Oomoo`1:Ool00`00Oomoo`1VOol00`00Oomoo`1BOol001Eoo`03001oogoo04]oo`03001oogoo06Ao
o`03001oogoo05=oo`005Goo00<007ooOol0Bgoo00<007ooOol0I7oo00<007ooOol0Dgoo000EOol0
0`00Oomoo`1<Ool00`00Oomoo`1ROol00`00Oomoo`1DOol001Eoo`8004ioo`03001oogoo065oo`03
001oogoo05Aoo`005Goo00<007ooOol0CGoo00<007ooOol0H7oo00<007ooOol0EGoo000EOol00`00
Oomoo`1>Ool00`00Oomoo`1OOol00`00Oomoo`1EOol001Eoo`03001oogoo04ioo`03001oogoo05io
o`03001oogoo05Ioo`005Goo00<007ooOol0Cgoo00<007ooOol0GGoo00<007ooOol0EWoo000EOol0
0`00Oomoo`1?Ool00`00Oomoo`1LOol00`00Oomoo`1GOol001Eoo`03001oogoo051oo`03001oogoo
05]oo`03001oogoo05Moo`005Goo0P00DGoo00<007ooOol0FWoo00<007ooOol0F7oo000EOol00`00
Oomoo`1AOol00`00Oomoo`1IOol00`00Oomoo`1HOol001Eoo`03001oogoo055oo`03001oogoo05Qo
o`03001oogoo05Uoo`005Goo00<007ooOol0DWoo00<007ooOol0EWoo00<007ooOol0FWoo0002Ool2
0004Ool20004Ool20005Ool00`00Oomoo`1BOol00`00Oomoo`1EOol00`00Oomoo`1KOol00005Ool0
07ooOol00008Ool01000Oomoo`0017oo00<007ooOol0Dgoo00<007ooOol0E7oo00<007ooOol0Fgoo
00001Goo001oogoo00002goo00<007ooOol00Woo0`00DgooF000GGoo00001Goo001oogoo00002Goo
0P001Goo00<007ooOol0ogoo2Goo00001Goo001oogoo00002Goo00<007ooOol017oo00<007ooOol0
ogoo2Goo0002Ool2000:Ool30004Ool00`00Oomoo`3oOol9Ool001Eoo`03001oogoo0?moo`Uoo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.248956, -0.0387349, \
0.0115854, 0.00312425}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[14]="]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 723}},
WindowToolbars->"EditBar",
WindowSize->{480, 644},
WindowMargins->{{18, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
CellLabelAutoDelete->False,
Magnification->1,
StyleDefinitions -> "Default.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 30, 0, 53, "Section"],
Cell[1772, 53, 562, 17, 106, "Text"],
Cell[2337, 72, 95, 2, 33, "Text"],
Cell[2435, 76, 108, 3, 33, "Text"],
Cell[2546, 81, 95, 2, 30, "Input"],
Cell[2644, 85, 110, 2, 42, "Input"],
Cell[2757, 89, 112, 2, 30, "Input"],

Cell[CellGroupData[{
Cell[2894, 95, 143, 3, 41, "Input"],
Cell[3040, 100, 241, 4, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3318, 109, 75, 2, 30, "Input"],
Cell[3396, 113, 15483, 441, 186, 4192, 296, "GraphicsData", "PostScript", \
"Graphics"],
Cell[18882, 556, 154, 4, 29, "Output"]
}, Open  ]],
Cell[19051, 563, 125, 3, 52, "Text"],
Cell[19179, 568, 95, 2, 30, "Input"],

Cell[CellGroupData[{
Cell[19299, 574, 97, 2, 30, "Input"],
Cell[19399, 578, 12688, 398, 186, 4159, 288, "GraphicsData", "PostScript", \
"Graphics"],
Cell[32090, 978, 154, 4, 29, "Output"]
}, Open  ]],
Cell[32259, 985, 57, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[32341, 989, 95, 2, 30, "Input"],
Cell[32439, 993, 164, 3, 52, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32640, 1001, 95, 2, 30, "Input"],
Cell[32738, 1005, 170, 3, 52, "Output"]
}, Open  ]],
Cell[32923, 1011, 110, 3, 33, "Text"],
Cell[33036, 1016, 100, 2, 32, "Input"],

Cell[CellGroupData[{
Cell[33161, 1022, 113, 2, 30, "Input"],
Cell[33277, 1026, 220, 5, 76, "Output"]
}, Open  ]],
Cell[33512, 1034, 52, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[33589, 1038, 80, 2, 30, "Input"],
Cell[33672, 1042, 15484, 441, 186, 4192, 296, "GraphicsData", "PostScript", \
"Graphics"],
Cell[49159, 1485, 155, 4, 29, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

